@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # @api private
 module Nanoc::Int
 end
@@ -5,7 +7,6 @@ end
 require_relative 'base/core_ext'
 require_relative 'base/contracts_support'
 require_relative 'base/memoization'
-require_relative 'base/plugin_registry'
 require_relative 'base/error'
 require_relative 'base/errors'
 
