@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc
   module Int
     # @api private
@@ -64,6 +66,13 @@ module Nanoc
         self
       end
 
+      contract String => self
+      def with_identifier_prefix(prefix)
+        other = dup
+        other.identifier = @identifier.prefix(prefix)
+        other
+      end
+
       contract C::None => String
       # @abstract
       #
