@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::Int
   # Module that contains all Nanoc-specific errors.
   #
@@ -68,12 +70,20 @@ module Nanoc::Int
 
     # Error that is raised during site compilation when an item (directly or
     # indirectly) includes its own item content, leading to endless recursion.
-    class RecursiveCompilation < Generic
-      # @param [Array<Nanoc::Int::ItemRep>] reps A list of item representations
-      #   that mutually depend on each other
-      def initialize(reps)
-        list = reps.map(&:inspect).join("\n")
-        super("The site cannot be compiled because the following items mutually depend on each other:\n#{list}.")
+    class DependencyCycle < Generic
+      def initialize(stack)
+        start_idx = stack.index(stack.last)
+        cycle = stack[start_idx..-2]
+
+        msg_bits = []
+        msg_bits << 'The site cannot be compiled because there is a dependency cycle:'
+        msg_bits << ''
+        cycle.each.with_index do |r, i|
+          msg_bits << "    (#{i + 1}) item #{r.item.identifier}, rep #{r.name.inspect}, uses compiled content of"
+        end
+        msg_bits << msg_bits.pop + ' (1)'
+
+        super(msg_bits.map { |x| x + "\n" }.join(''))
       end
     end
 
@@ -125,7 +135,7 @@ module Nanoc::Int
       # @param [Nanoc::Int::ItemRep] rep The item representation that was attempted
       #   to be laid out
       def initialize(rep)
-        super("The “{rep.item.identifier}” item (rep “#{rep.name}”) cannot be laid out because it is a binary item. If you are getting this error for an item that should be textual instead of binary, make sure that its extension is included in the text_extensions array in the site configuration.")
+        super("The “#{rep.item.identifier}” item (rep “#{rep.name}”) cannot be laid out because it is a binary item. If you are getting this error for an item that should be textual instead of binary, make sure that its extension is included in the text_extensions array in the site configuration.")
       end
     end
 
