@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'weakref'
 
 module Nanoc::Int
@@ -5,23 +7,6 @@ module Nanoc::Int
   #
   # @api private
   module Memoization
-    class Wrapper
-      attr_reader :ref
-
-      def initialize(ref)
-        @ref = ref
-      end
-
-      def inspect
-        obj = @ref.object
-        if obj
-          obj.inspect
-        else
-          '<garbage collected>'
-        end
-      end
-    end
-
     class Value
       attr_reader :value
 
@@ -69,25 +54,29 @@ module Nanoc::Int
       original_method_name = '__nonmemoized_' + method_name.to_s
       alias_method original_method_name, method_name
 
+      instance_cache = Hash.new { |hash, key| hash[key] = {} }
+
       define_method(method_name) do |*args|
-        @__memoization_cache ||= {}
-        @__memoization_cache[method_name] ||= {}
-        method_cache = @__memoization_cache[method_name]
+        instance_method_cache = instance_cache[self]
 
         value = NONE
-        if method_cache.key?(args)
-          object = method_cache[args].ref.object
+        if instance_method_cache.key?(args)
+          object = instance_method_cache[args].object
           value = object ? object.value : NONE
         end
 
+        counter_label = is_a?(Class) ? "#{self}.#{method_name}" : "#{self.class}##{method_name}"
         if value.equal?(NONE)
+          Nanoc::Int::NotificationCenter.post(:memoization_miss, counter_label)
           send(original_method_name, *args).tap do |r|
-            method_cache[args] = Wrapper.new(Ref::SoftReference.new(Value.new(r)))
+            instance_method_cache[args] = Ref::SoftReference.new(Value.new(r))
           end
         else
+          Nanoc::Int::NotificationCenter.post(:memoization_hit, counter_label)
           value
         end
       end
     end
+    alias memoized memoize
   end
 end
