@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::Int
   # @api private
   class OutdatednessStore < ::Nanoc::Int::Store
@@ -5,7 +7,7 @@ module Nanoc::Int
 
     contract C::KeywordArgs[site: C::Maybe[Nanoc::Int::Site], reps: Nanoc::Int::ItemRepRepo] => C::Any
     def initialize(site: nil, reps:)
-      super(Nanoc::Int::Store.tmp_path_for(env_name: (site.config.env_name if site), store_name: 'outdatedness'), 1)
+      super(Nanoc::Int::Store.tmp_path_for(site: site, store_name: 'outdatedness'), 1)
 
       @outdated_reps = Set.new
       @all_reps = reps
