@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::Int
   class SiteLoader
     def new_empty
@@ -23,27 +25,19 @@ module Nanoc::Int
       code_snippets = code_snippets_from_config(config)
       code_snippets.each(&:load)
 
-      items = Nanoc::Int::IdentifiableCollection.new(config)
-      layouts = Nanoc::Int::IdentifiableCollection.new(config)
-
-      with_data_sources(config) do |data_sources|
-        data_sources.each do |ds|
-          items_in_ds = ds.items
-          layouts_in_ds = ds.layouts
-
-          items_in_ds.each { |i| i.identifier = i.identifier.prefix(ds.items_root) }
-          layouts_in_ds.each { |l| l.identifier = l.identifier.prefix(ds.layouts_root) }
-
-          items.concat(items_in_ds)
-          layouts.concat(layouts_in_ds)
+      data_sources_to_aggregate =
+        with_data_sources(config) do |data_sources|
+          data_sources.map do |ds|
+            Nanoc::Int::PrefixedDataSource.new(ds, ds.items_root, ds.layouts_root)
+          end
         end
-      end
+
+      data_source = Nanoc::Int::AggregateDataSource.new(data_sources_to_aggregate, config)
 
       Nanoc::Int::Site.new(
         config: config,
         code_snippets: code_snippets,
-        items: items,
-        layouts: layouts,
+        data_source: data_source,
       )
     end
 
@@ -61,7 +55,7 @@ module Nanoc::Int
     def create_data_sources(config)
       config[:data_sources].map do |data_source_hash|
         # Get data source class
-        data_source_class = Nanoc::DataSource.named(data_source_hash[:type])
+        data_source_class = Nanoc::DataSource.named(data_source_hash[:type].to_sym)
         if data_source_class.nil?
           raise Nanoc::Int::Errors::UnknownDataSource.new(data_source_hash[:type])
         end
@@ -80,11 +74,31 @@ module Nanoc::Int
       config[:lib_dirs].flat_map do |lib|
         Dir["#{lib}/**/*.rb"].sort.map do |filename|
           Nanoc::Int::CodeSnippet.new(
-            File.read(filename),
+            read_code_snippet_contents(filename),
             filename,
           )
         end
       end
     end
+
+    ENCODING_REGEX = /\A#\s+(-\*-\s+)?(en)?coding: (?<encoding>[^\s]+)(\s+-\*-\s*)?\n{0,2}/
+
+    def encoding_from_magic_comment(raw)
+      match = ENCODING_REGEX.match(raw)
+      match ? match['encoding'] : nil
+    end
+
+    def read_code_snippet_contents(filename)
+      raw = File.read(filename, encoding: 'ASCII-8BIT')
+
+      enc = encoding_from_magic_comment(raw)
+      if enc
+        raw = raw.force_encoding(enc).encode('UTF-8').sub(ENCODING_REGEX, '')
+      else
+        raw.force_encoding('UTF-8')
+      end
+
+      raw
+    end
   end
 end
