@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::Int
   # An abstract superclass for classes that need to store data to the
   # filesystem, such as checksums, cached compiled content and dependency
@@ -38,9 +40,16 @@ module Nanoc::Int
 
     # Logic for building tmp path from active environment and store name
     # @api private
-    contract C::KeywordArgs[env_name: C::Maybe[String], store_name: String] => String
-    def self.tmp_path_for(env_name:, store_name:)
-      File.join('tmp', env_name.to_s, store_name)
+    contract C::KeywordArgs[site: C::Maybe[Nanoc::Int::Site], store_name: String] => String
+    def self.tmp_path_for(store_name:, site:)
+      # FIXME: disallow site from being nil
+      output_dir = site ? site.config.output_dir : ''
+      File.join(tmp_path_prefix(output_dir), store_name)
+    end
+
+    def self.tmp_path_prefix(output_dir)
+      dir = Digest::SHA1.hexdigest(output_dir)[0..12]
+      File.join('tmp', 'nanoc', dir)
     end
 
     # @group Loading and storing data
