@@ -1,5 +1,9 @@
+# frozen_string_literal: true
+
 require_relative 'services/action_provider'
+require_relative 'services/action_sequence_builder'
 require_relative 'services/checksummer'
+require_relative 'services/compilation_context'
 require_relative 'services/compiler'
 require_relative 'services/compiler_loader'
 require_relative 'services/dependency_tracker'
@@ -15,4 +19,7 @@ require_relative 'services/temp_filename_factory'
 require_relative 'services/outdatedness_rule'
 require_relative 'services/outdatedness_rules'
 
+require_relative 'services/compiler/phases'
+require_relative 'services/compiler/stages'
+
 require_relative 'services/outdatedness_checker'
