@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 module Nanoc::Int
   # @private
   class ActionProvider
-    extend Nanoc::Int::PluginRegistry::PluginMethods
+    extend DDPlugin::Plugin
 
     def self.for(_site)
       raise NotImplementedError
@@ -11,16 +13,20 @@ module Nanoc::Int
       raise NotImplementedError
     end
 
-    def memory_for(_rep)
+    def action_sequence_for(_rep)
       raise NotImplementedError
     end
 
-    def snapshots_defs_for(_rep)
+    def need_preprocessing?
       raise NotImplementedError
     end
 
-    def paths_for(rep)
-      memory_for(rep).paths
+    def preprocess(_site)
+      raise NotImplementedError
+    end
+
+    def postprocess(_site, _reps)
+      raise NotImplementedError
     end
   end
 end
