@@ -1,11 +1,29 @@
+# frozen_string_literal: true
+
 module Nanoc::Int
   # @api private
   class ItemRepWriter
-    TMP_TEXT_ITEMS_DIR = 'text_items'.freeze
+    TMP_TEXT_ITEMS_DIR = 'text_items'
 
-    def write(item_rep, snapshot_name)
-      raw_path = item_rep.raw_path(snapshot: snapshot_name)
-      return unless raw_path
+    def write_all(item_rep, snapshot_repo)
+      written_paths = Set.new
+
+      item_rep.snapshot_defs.map(&:name).each do |snapshot_name|
+        write(item_rep, snapshot_repo, snapshot_name, written_paths)
+      end
+    end
+
+    def write(item_rep, snapshot_repo, snapshot_name, written_paths)
+      item_rep.raw_paths.fetch(snapshot_name, []).each do |raw_path|
+        write_single(item_rep, snapshot_repo, snapshot_name, raw_path, written_paths)
+      end
+    end
+
+    def write_single(item_rep, snapshot_repo, snapshot_name, raw_path, written_paths)
+      # Don’t write twice
+      # TODO: test written_paths behavior
+      return if written_paths.include?(raw_path)
+      written_paths << raw_path
 
       # Create parent directory
       FileUtils.mkdir_p(File.dirname(raw_path))
@@ -18,7 +36,7 @@ module Nanoc::Int
         :will_write_rep, item_rep, raw_path
       )
 
-      content = item_rep.snapshot_contents[snapshot_name]
+      content = snapshot_repo.get(item_rep, snapshot_name)
       if content.binary?
         temp_path = content.filename
       else
@@ -36,7 +54,7 @@ module Nanoc::Int
 
       # Notify
       Nanoc::Int::NotificationCenter.post(
-        :rep_written, item_rep, raw_path, is_created, is_modified
+        :rep_written, item_rep, content.binary?, raw_path, is_created, is_modified
       )
     end
 
