@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc
   class ConfigView < ::Nanoc::View
     # @api private
@@ -16,6 +18,7 @@ module Nanoc
 
     # @see Hash#fetch
     def fetch(key, fallback = NONE, &_block)
+      @context.dependency_tracker.bounce(unwrap, attributes: [key])
       @config.fetch(key) do
         if !fallback.equal?(NONE)
           fallback
@@ -29,16 +32,19 @@ module Nanoc
 
     # @see Hash#key?
     def key?(key)
+      @context.dependency_tracker.bounce(unwrap, attributes: [key])
       @config.key?(key)
     end
 
     # @see Hash#[]
     def [](key)
+      @context.dependency_tracker.bounce(unwrap, attributes: [key])
       @config[key]
     end
 
     # @see Hash#each
     def each(&block)
+      @context.dependency_tracker.bounce(unwrap, attributes: true)
       @config.each(&block)
     end
   end
