@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc
   module MutableDocumentViewMixin
     # @api private
@@ -13,6 +15,10 @@ module Nanoc
       end
     end
 
+    def raw_content=(arg)
+      unwrap.content = Nanoc::Int::Content.create(arg)
+    end
+
     # Sets the value for the given attribute.
     #
     # @param [Symbol] key
