@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc
   class MutableIdentifiableCollectionView < Nanoc::IdentifiableCollectionView
     # Deletes every object for which the block evaluates to true.
@@ -8,7 +10,7 @@ module Nanoc
     #
     # @return [self]
     def delete_if(&_block)
-      @objects.delete_if { |o| yield(view_class.new(o, @context)) }
+      @objects = @objects.reject { |o| yield(view_class.new(o, @context)) }
       self
     end
   end
