@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc
   class MutableLayoutCollectionView < Nanoc::MutableIdentifiableCollectionView
     # @api private
@@ -15,7 +17,7 @@ module Nanoc
     #
     # @return [self]
     def create(content, attributes, identifier)
-      @objects << Nanoc::Int::Layout.new(content, attributes, identifier)
+      @objects = @objects.add(Nanoc::Int::Layout.new(content, attributes, identifier))
       self
     end
   end
