@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::Checking
   # @api private
   class OutputDirNotFoundError < Nanoc::Int::Errors::Generic
@@ -8,7 +10,7 @@ module Nanoc::Checking
 
   # @api private
   class Check < Nanoc::Int::Context
-    extend Nanoc::Int::PluginRegistry::PluginMethods
+    extend DDPlugin::Plugin
 
     attr_reader :issues
 
@@ -23,7 +25,7 @@ module Nanoc::Checking
       view_context = site.compiler.compilation_context.create_view_context(Nanoc::Int::DependencyTracker::Null.new)
 
       context = {
-        items: Nanoc::ItemCollectionWithRepsView.new(site.items, view_context),
+        items: Nanoc::PostCompileItemCollectionView.new(site.items, view_context),
         layouts: Nanoc::LayoutCollectionView.new(site.layouts, view_context),
         config: Nanoc::ConfigView.new(site.config, view_context),
         output_filenames: output_filenames,
