@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module ::Nanoc::Checking::Checks
   # @api private
   class HTML < ::Nanoc::Checking::Checks::W3CValidator
@@ -8,7 +10,7 @@ module ::Nanoc::Checking::Checks
     end
 
     def validator_class
-      ::W3CValidators::MarkupValidator
+      ::W3CValidators::NuValidator
     end
   end
 end
