@@ -1,9 +1,13 @@
+# frozen_string_literal: true
+
 module Nanoc::Checking::Checks
   # A check that verifies HTML files do not reference external resources with
   # URLs that would trigger "mixed content" warnings.
   #
   # @api private
   class MixedContent < ::Nanoc::Checking::Check
+    identifier :mixed_content
+
     PROTOCOL_PATTERN = /^(\w+):\/\//
 
     def run
