@@ -1,6 +1,10 @@
+# frozen_string_literal: true
+
 module Nanoc::Checking::Checks
   # @api private
   class Stale < ::Nanoc::Checking::Check
+    identifier :stale
+
     def run
       require 'set'
 
@@ -24,7 +28,8 @@ module Nanoc::Checking::Checks
             .flat_map(&:reps)
             .map(&:unwrap)
             .flat_map(&:raw_paths)
-            .flat_map(&:values),
+            .flat_map(&:values)
+            .flatten,
         )
     end
 
