@@ -1,8 +1,11 @@
+# frozen_string_literal: true
+
 module ::Nanoc::Checking::Checks
   # @api private
   class W3CValidator < ::Nanoc::Checking::Check
     def run
       require 'w3c_validators'
+      require 'resolv-replace'
 
       Dir[@config[:output_dir] + '/**/*.' + extension].each do |filename|
         results = validator_class.new.validate_file(filename)
