@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::CLI
   # An output stream that passes output through stream cleaners. This can be
   # used to strip ANSI color sequences, for instance.
@@ -147,7 +149,7 @@ module Nanoc::CLI
     protected
 
     def _nanoc_clean(s)
-      @stream_cleaners.reduce(s.to_s) { |acc, elem| elem.clean(acc) }
+      @stream_cleaners.reduce(s.to_s.scrub) { |acc, elem| elem.clean(acc) }
     end
 
     def _nanoc_swallow_broken_pipe_errors_while
