@@ -1,22 +1,23 @@
+# frozen_string_literal: true
+
 usage 'shell'
 summary 'open a shell on the Nanoc environment'
 aliases 'console'
 description "
 Open an IRB shell on a context that contains @items, @layouts, and @config.
 "
+flag :p, :preprocess, 'run preprocessor'
 
 module Nanoc::CLI::Commands
   class Shell < ::Nanoc::CLI::CommandRunner
     def run
       require 'pry'
 
-      load_site
+      load_site(preprocess: options[:preprocess])
 
       Nanoc::Int::Context.new(env).pry
     end
 
-    protected
-
     def env
       self.class.env_for_site(site)
     end
@@ -35,6 +36,7 @@ module Nanoc::CLI::Commands
         items: site.items,
         dependency_tracker: Nanoc::Int::DependencyTracker::Null.new,
         compilation_context: nil,
+        snapshot_repo: nil,
       )
     end
 
