@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 summary 'show all available plugins'
 aliases :info
 usage 'show-plugins [options]'
-description <<-EOS
-Show a list of available plugins, including filters and data sources.
-If the current directory contains a Nanoc web site, the plugins defined in this site will be shown as well.
+description <<~EOS
+  Show a list of available plugins, including filters and data sources.
+  If the current directory contains a Nanoc web site, the plugins defined in this site will be shown as well.
 EOS
 
 module Nanoc::CLI::Commands
@@ -15,24 +17,24 @@ module Nanoc::CLI::Commands
       end
 
       # Get list of plugins (before and after)
-      plugins_before = Nanoc::Int::PluginRegistry.instance.all
-      site.code_snippets if site
-      plugins_after = Nanoc::Int::PluginRegistry.instance.all
+      plugins_before = PLUGIN_CLASSES.keys.each_with_object({}) { |c, acc| acc[c] = c.all }
+      site&.code_snippets
+      plugins_after = PLUGIN_CLASSES.keys.each_with_object({}) { |c, acc| acc[c] = c.all }
 
       # Divide list of plugins into builtin and custom
       plugins_builtin = plugins_before
-      plugins_custom  = plugins_after - plugins_before
+      plugins_custom  = plugins_after.each_with_object({}) do |(superclass, klasses), acc|
+        acc[superclass] = klasses - plugins_before[superclass]
+      end
 
       # Find max identifiers length
-      plugin_with_longest_identifiers = plugins_after.reduce do |longest, current|
-        longest[:identifiers].join(', ').size > current[:identifiers].join(', ').size ? longest : current
-      end
-      max_identifiers_length = plugin_with_longest_identifiers[:identifiers].join(', ').size
+      all_identifiers = plugins_after.values.flatten.map(&:identifiers)
+      max_identifiers_length = all_identifiers.map(&:to_s).map(&:size).max
 
       PLUGIN_CLASS_ORDER.each do |superclass|
         plugins_with_this_superclass = {
-          builtin: plugins_builtin.select { |p| p[:superclass] == superclass },
-          custom: plugins_custom.select { |p| p[:superclass] == superclass },
+          builtin: plugins_builtin.fetch(superclass, []),
+          custom: plugins_custom.fetch(superclass, []),
         }
 
         # Print kind
@@ -41,7 +43,7 @@ module Nanoc::CLI::Commands
         puts
 
         # Print plugins organised by subtype
-        [:builtin, :custom].each do |type|
+        %i[builtin custom].each do |type|
           # Find relevant plugins
           relevant_plugins = plugins_with_this_superclass[type]
 
@@ -53,12 +55,12 @@ module Nanoc::CLI::Commands
           end
 
           # Print plugins
-          relevant_plugins.sort_by { |k| k[:identifiers].join(', ') }.each do |plugin|
+          relevant_plugins.sort_by { |k| k.identifiers.join(', ') }.each do |plugin|
             # Display
             puts format(
               "    %-#{max_identifiers_length}s (%s)",
-              plugin[:identifiers].join(', '),
-              plugin[:class].to_s.sub(/^::/, ''),
+              plugin.identifiers.join(', '),
+              plugin.to_s.sub(/^::/, ''),
             )
           end
         end
