@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::CLI
   # Catches errors and prints nice diagnostic messages, then exits.
   #
@@ -42,7 +44,7 @@ module Nanoc::CLI
     # @return [void]
     def handle_while(&_block)
       # Set exit handler
-      %w(INT TERM).each do |signal|
+      %w[INT TERM].each do |signal|
         Signal.trap(signal) do
           puts
           exit!(0)
@@ -179,6 +181,7 @@ module Nanoc::CLI
       'builder'        => 'builder',
       'coderay'        => 'coderay',
       'cri'            => 'cri',
+      'erubi'          => 'erubi',
       'erubis'         => 'erubis',
       'escape'         => 'escape',
       'fog'            => 'fog',
@@ -192,6 +195,7 @@ module Nanoc::CLI
       'maruku'         => 'maruku',
       'mime/types'     => 'mime-types',
       'nokogiri'       => 'nokogiri',
+      'nokogumbo'      => 'nokogumbo',
       'pry'            => 'pry',
       'rack'           => 'rack',
       'rack/cache'     => 'rack-cache',
