@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::CLI::StreamCleaners
   # Simplifies output by replacing UTF-8 characters with their ASCII decompositions.
   #
@@ -6,7 +8,10 @@ module Nanoc::CLI::StreamCleaners
     # @see Nanoc::CLI::StreamCleaners::Abstract#clean
     def clean(s)
       # FIXME: this decomposition is not generally usable
-      s.gsub(/“|”/, '"').gsub(/‘|’/, '\'').gsub('…', '...').gsub('©', '(c)')
+      s
+        .unicode_normalize(:nfkd)
+        .tr('─┼“”‘’', '-+""\'\'')
+        .gsub('©', '(c)')
     end
   end
 end
