@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::DataSources
   # The filesystem data source stores its items and layouts in nested
   # directories. Items and layouts are represented by one or two files; if it
@@ -46,6 +48,8 @@ module Nanoc::DataSources
   #
   # @api private
   class Filesystem < Nanoc::DataSource
+    identifiers :filesystem, :filesystem_unified
+
     # See {Nanoc::DataSource#up}.
     def up; end
 
@@ -162,7 +166,7 @@ module Nanoc::DataSources
             content,
             attributes,
             identifier,
-            content_checksum_data: proto_doc.content_checksum_data,
+            content_checksum_data: content_checksum_data_for(proto_doc),
             attributes_checksum_data: attributes_checksum_data_for(proto_doc, content_filename, meta_filename),
           )
         end
@@ -171,10 +175,18 @@ module Nanoc::DataSources
       res
     end
 
+    def content_checksum_data_for(proto_doc)
+      Digest::SHA1.digest(
+        proto_doc.content_checksum_data || '',
+      )
+    end
+
     def attributes_checksum_data_for(proto_doc, content_filename, meta_filename)
-      YAML.dump(
-        attributes: proto_doc.attributes_checksum_data,
-        extra_attributes: extra_attributes_for(content_filename, meta_filename),
+      Digest::SHA1.digest(
+        Marshal.dump(
+          attributes: proto_doc.attributes_checksum_data,
+          extra_attributes: extra_attributes_for(content_filename, meta_filename),
+        ),
       )
     end
 
@@ -244,7 +256,7 @@ module Nanoc::DataSources
       by_basename.each_pair do |basename, filenames|
         # Divide
         meta_filenames    = filenames.select { |fn| ext_of(fn) == '.yaml' }
-        content_filenames = filenames.select { |fn| ext_of(fn) != '.yaml' }
+        content_filenames = filenames.reject { |fn| ext_of(fn) == '.yaml' }
 
         # Check number of files per type
         unless [0, 1].include?(meta_filenames.size)
@@ -300,9 +312,9 @@ module Nanoc::DataSources
 
       regex =
         if filename =~ /(^|\/)index(\.[^\/]+)?$/
-          @config && @config[:allow_periods_in_identifiers] ? /\/?(index)?(\.[^\/\.]+)?$/ : /\/?index(\.[^\/]+)?$/
+          allow_periods_in_identifiers? ? /\/?(index)?(\.[^\/\.]+)?$/ : /\/?index(\.[^\/]+)?$/
         else
-          @config && @config[:allow_periods_in_identifiers] ? /\.[^\/\.]+$/ : /\.[^\/]+$/
+          allow_periods_in_identifiers? ? /\.[^\/\.]+$/ : /\.[^\/]+$/
         end
       Nanoc::Identifier.new(filename.sub(regex, ''), type: :legacy)
     end
@@ -327,13 +339,21 @@ module Nanoc::DataSources
     #
     # @return [Regex]
     def extension_regex
-      if @config && @config[:allow_periods_in_identifiers]
+      if allow_periods_in_identifiers?
         /(\.[^\/\.]+$)/
       else
         /(\.[^\/]+$)/
       end
     end
 
+    def allow_periods_in_identifiers?
+      if @config
+        @config[:allow_periods_in_identifiers] || @config[:identifier_type] == 'full'
+      else
+        false
+      end
+    end
+
     # @return [ParseResult]
     def parse(content_filename, meta_filename)
       if meta_filename
@@ -413,24 +433,24 @@ module Nanoc::DataSources
         raise Errors::FileUnreadable.new(filename, e)
       end
 
-      # Fix
-      if data.respond_to?(:encode!)
-        if @config && @config[:encoding]
-          original_encoding = Encoding.find(@config[:encoding])
-          data.force_encoding(@config[:encoding])
-        else
-          original_encoding = data.encoding
-        end
+      # Set original encoding, if any
+      if @config && @config[:encoding]
+        original_encoding = Encoding.find(@config[:encoding])
+        data.force_encoding(@config[:encoding])
+      else
+        original_encoding = data.encoding
+      end
 
-        begin
-          data.encode!('UTF-8')
-        rescue
-          raise Errors::InvalidEncoding.new(filename, original_encoding)
-        end
+      # Set encoding to UTF-8
+      begin
+        data.encode!('UTF-8')
+      rescue
+        raise Errors::InvalidEncoding.new(filename, original_encoding)
+      end
 
-        unless data.valid_encoding?
-          raise Errors::InvalidEncoding.new(filename, original_encoding)
-        end
+      # Verify
+      unless data.valid_encoding?
+        raise Errors::InvalidEncoding.new(filename, original_encoding)
       end
 
       # Remove UTF-8 BOM (ugly)
