@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::Deploying
   # Represents a deployer, an object that allows uploading the compiled site
   # to a specific (remote) location.
@@ -6,7 +8,7 @@ module Nanoc::Deploying
   #
   # @api private
   class Deployer
-    extend Nanoc::Int::PluginRegistry::PluginMethods
+    extend DDPlugin::Plugin
 
     # @return [String] The path to the directory that contains the files to
     #   upload. It should not have a trailing slash.
