@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'thread'
 
 module Nanoc::Extra
@@ -7,7 +9,7 @@ module Nanoc::Extra
 
     include Nanoc::Int::ContractsSupport
 
-    contract C::RespondTo[:each], C::KeywordArgs[parallelism: Fixnum] => C::Any
+    contract C::RespondTo[:each], C::KeywordArgs[parallelism: Integer] => C::Any
     def initialize(enum, parallelism: 2)
       @enum = enum
       @parallelism = parallelism
