@@ -1,6 +1,10 @@
+# frozen_string_literal: true
+
 module Nanoc::Filters
   # @api private
   class CoffeeScript < Nanoc::Filter
+    identifier :coffeescript
+
     requires 'coffee-script'
 
     # Runs the content through [CoffeeScript](http://coffeescript.org/).
