@@ -1,6 +1,10 @@
+# frozen_string_literal: true
+
 module Nanoc::Filters
   # @api private
   class Less < Nanoc::Filter
+    identifier :less
+
     requires 'less'
 
     # Runs the content through [LESS](http://lesscss.org/).
