@@ -1,6 +1,10 @@
+# frozen_string_literal: true
+
 module Nanoc::Filters
   # @api private
   class Rainpress < Nanoc::Filter
+    identifier :rainpress
+
     requires 'rainpress'
 
     # Runs the content through [Rainpress](http://code.google.com/p/rainpress/).
