@@ -1,6 +1,10 @@
+# frozen_string_literal: true
+
 module Nanoc::Filters
   # @api private
   class RelativizePaths < Nanoc::Filter
+    identifier :relativize_paths
+
     require 'nanoc/helpers/link_to'
     include Nanoc::Helpers::LinkTo
 
@@ -36,7 +40,7 @@ module Nanoc::Filters
       case params[:type]
       when :css
         relativize_css(content)
-      when :html, :xml, :xhtml
+      when :html, :html5, :xml, :xhtml
         relativize_html_like(content, params)
       else
         raise 'The relativize_paths needs to know the type of content to ' \
@@ -61,22 +65,40 @@ module Nanoc::Filters
       namespaces = params.fetch(:namespaces, {})
       type       = params.fetch(:type)
 
-      require 'nokogiri'
+      parser = parser_for(type)
+      content = fix_content(content, type)
+
+      nokogiri_process(content, selectors, namespaces, parser, type)
+    end
+
+    def parser_for(type)
       case type
       when :html
-        klass = ::Nokogiri::HTML
+        require 'nokogiri'
+        ::Nokogiri::HTML
+      when :html5
+        require 'nokogumbo'
+        ::Nokogiri::HTML5
       when :xml
-        klass = ::Nokogiri::XML
+        require 'nokogiri'
+        ::Nokogiri::XML
+      when :xhtml
+        require 'nokogiri'
+        ::Nokogiri::XML
+      end
+    end
+
+    def fix_content(content, type)
+      case type
       when :xhtml
-        klass = ::Nokogiri::XML
         # FIXME: cleanup because it is ugly
         # this cleans the XHTML namespace to process fragments and full
         # documents in the same way. At least, Nokogiri adds this namespace
         # if detects the `html` element.
-        content = content.sub(%r{(<html[^>]+)xmlns="http://www.w3.org/1999/xhtml"}, '\1')
+        content.sub(%r{(<html[^>]+)xmlns="http://www.w3.org/1999/xhtml"}, '\1')
+      else
+        content
       end
-
-      nokogiri_process(content, selectors, namespaces, klass, type)
     end
 
     def nokogiri_process(content, selectors, namespaces, klass, type)
@@ -84,16 +106,21 @@ module Nanoc::Filters
       namespaces = namespaces.reduce({}) { |new, (prefix, uri)| new.merge(prefix.to_s => uri) }
 
       doc = content =~ /<html[\s>]/ ? klass.parse(content) : klass.fragment(content)
-      selectors.map { |sel| "descendant-or-self::#{sel}" }.each do |selector|
-        doc.xpath(selector, namespaces).each do |node|
-          if node.name == 'comment'
-            nokogiri_process_comment(node, doc, selectors, namespaces, klass, type)
-          elsif path_is_relativizable?(node.content)
-            node.content = relative_path_to(node.content)
-          end
+      selector = selectors.map { |sel| "descendant-or-self::#{sel}" }.join('|')
+      doc.xpath(selector, namespaces).each do |node|
+        if node.name == 'comment'
+          nokogiri_process_comment(node, doc, selectors, namespaces, klass, type)
+        elsif path_is_relativizable?(node.content)
+          node.content = relative_path_to(node.content)
         end
       end
-      doc.send("to_#{type}")
+
+      case type
+      when :html5
+        doc.to_html
+      else
+        doc.send("to_#{type}")
+      end
     end
 
     def nokogiri_process_comment(node, doc, selectors, namespaces, klass, type)
