@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::Helpers
   # @see http://nanoc.ws/doc/reference/helpers/#blogging
   module Blogging
@@ -50,7 +52,7 @@ module Nanoc::Helpers
       end
 
       def build
-        buffer = ''
+        buffer = String.new
         xml = Builder::XmlMarkup.new(target: buffer, indent: 2)
         build_for_feed(xml)
         buffer
@@ -104,10 +106,9 @@ module Nanoc::Helpers
       end
 
       def build_for_feed(xml)
+        root_url = @config[:base_url] + '/'
         xml.instruct!
-        xml.feed(xmlns: 'http://www.w3.org/2005/Atom') do
-          root_url = @config[:base_url] + '/'
-
+        xml.feed(xmlns: 'http://www.w3.org/2005/Atom', 'xml:base' => root_url) do
           # Add primary attributes
           xml.id root_url
           xml.title title
