@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc::Helpers
   # @see http://nanoc.ws/doc/reference/helpers/#filtering
   module Filtering
@@ -13,8 +15,7 @@ module Nanoc::Helpers
       data = capture(&block)
 
       # Find filter
-      klass = Nanoc::Filter.named(filter_name)
-      raise Nanoc::Int::Errors::UnknownFilter.new(filter_name) if klass.nil?
+      klass = Nanoc::Filter.named!(filter_name)
 
       # Create filter
       assigns = {
