@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 require_relative 'rule_dsl/compiler_dsl'
 require_relative 'rule_dsl/action_provider'
 require_relative 'rule_dsl/recording_executor'
 require_relative 'rule_dsl/rule_context'
-require_relative 'rule_dsl/rule_memory_calculator'
+require_relative 'rule_dsl/action_sequence_calculator'
 require_relative 'rule_dsl/rule'
 require_relative 'rule_dsl/rules_collection'
 require_relative 'rule_dsl/rules_loader'
