@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Nanoc
   # @api private
   module Spec
@@ -11,12 +13,12 @@ module Nanoc
       def initialize(mod)
         @mod = mod
 
-        @erbout = ''
-        @rule_memory = {}
+        @erbout = String.new
+        @action_sequence = {}
         @config = Nanoc::Int::Configuration.new.with_defaults
         @reps = Nanoc::Int::ItemRepRepo.new
-        @items = Nanoc::Int::IdentifiableCollection.new(@config)
-        @layouts = Nanoc::Int::IdentifiableCollection.new(@config)
+        @items = Nanoc::Int::ItemCollection.new(@config)
+        @layouts = Nanoc::Int::LayoutCollection.new(@config)
         @dependency_tracker = Nanoc::Int::DependencyTracker.new(Object.new)
       end
 
@@ -31,8 +33,8 @@ module Nanoc
       # @return [Nanoc::ItemWithRepsView] A view for the newly created item
       def create_item(content, attributes, identifier)
         item = Nanoc::Int::Item.new(content, attributes, identifier)
-        @items << item
-        Nanoc::ItemWithRepsView.new(item, view_context)
+        @items = @items.add(item)
+        self
       end
 
       # Creates a new layout and adds it to the site’s collection of layouts.
@@ -46,8 +48,8 @@ module Nanoc
       # @return [Nanoc::ItemWithRepsView] A view for the newly created layout
       def create_layout(content, attributes, identifier)
         layout = Nanoc::Int::Layout.new(content, attributes, identifier)
-        @layouts << layout
-        Nanoc::LayoutView.new(layout, view_context)
+        @layouts = @layouts.add(layout)
+        self
       end
 
       # Creates a new representation for the given item.
@@ -58,9 +60,9 @@ module Nanoc
       # @param [Symbol] rep The rep name to create
       def create_rep(item, path, rep = :default)
         rep = Nanoc::Int::ItemRep.new(item.unwrap, rep)
-        rep.paths[:last] = path
+        rep.paths[:last] = [path]
         @reps << rep
-        Nanoc::ItemRepView.new(rep, view_context)
+        self
       end
 
       # @return [Object] An object that includes the helper functions
@@ -103,12 +105,16 @@ module Nanoc
         assigns[:layouts]
       end
 
-      def rule_memory_for(obj)
-        @rule_memory.fetch(obj, [])
+      def action_sequence_for(obj)
+        @action_sequence.fetch(obj, [])
       end
 
-      def update_rule_memory(obj, memory)
-        @rule_memory[obj] = memory
+      def update_action_sequence(obj, memory)
+        @action_sequence[obj] = memory
+      end
+
+      def snapshot_repo
+        view_context.snapshot_repo
       end
 
       private
@@ -118,7 +124,8 @@ module Nanoc
           reps: @reps,
           items: @items,
           dependency_tracker: @dependency_tracker,
-          compilation_context: new_site.compiler.compilation_context,
+          compilation_context: site.compiler.compilation_context,
+          snapshot_repo: site.compiler.compilation_context.snapshot_repo,
         )
       end
 
@@ -136,12 +143,12 @@ module Nanoc
             [:default]
           end
 
-          def memory_for(obj)
-            @context.rule_memory_for(obj)
+          def action_sequence_for(obj)
+            @context.action_sequence_for(obj)
           end
 
           def snapshots_defs_for(_rep)
-            [Nanoc::Int::SnapshotDef.new(:last)]
+            [Nanoc::Int::SnapshotDef.new(:last, binary: false)]
           end
         end.new(self)
       end
@@ -150,26 +157,19 @@ module Nanoc
         Nanoc::Int::CompilerLoader.new.load(site, action_provider: new_action_provider)
       end
 
-      def new_site
-        site = Nanoc::Int::Site.new(
-          config: @config,
-          code_snippets: [],
-          items: @items,
-          layouts: @layouts,
-        )
-        site.compiler = new_compiler_for(site)
-        site
+      def site
+        @_site ||= begin
+          site = Nanoc::Int::Site.new(
+            config: @config,
+            code_snippets: [],
+            data_source: Nanoc::Int::InMemDataSource.new(@items, @layouts),
+          )
+          site.compiler = new_compiler_for(site)
+          site
+        end
       end
 
       def assigns
-        site = Nanoc::Int::Site.new(
-          config: @config,
-          code_snippets: [],
-          items: @items,
-          layouts: @layouts,
-        )
-        site.compiler = new_compiler_for(site)
-
         {
           config: Nanoc::MutableConfigView.new(@config, view_context),
           item_rep: @item_rep ? Nanoc::ItemRepView.new(@item_rep, view_context) : nil,
