@@ -1,12 +1,15 @@
+# frozen_string_literal: true
+
 describe Nanoc::Int::Executor do
   let(:executor) { described_class.new(rep, compilation_context, dependency_tracker) }
 
   let(:compilation_context) do
-    Nanoc::Int::Compiler::CompilationContext.new(
+    Nanoc::Int::CompilationContext.new(
       action_provider: action_provider,
       reps: reps,
       site: site,
       compiled_content_cache: compiled_content_cache,
+      snapshot_repo: snapshot_repo,
     )
   end
 
@@ -18,6 +21,7 @@ describe Nanoc::Int::Executor do
   let(:reps) { double(:reps) }
   let(:site) { double(:site) }
   let(:compiled_content_cache) { double(:compiled_content_cache) }
+  let(:snapshot_repo) { Nanoc::Int::SnapshotRepo.new }
 
   let(:dependency_tracker) { Nanoc::Int::DependencyTracker.new(double(:dependency_store)) }
 
@@ -31,29 +35,61 @@ describe Nanoc::Int::Executor do
     end
 
     context 'normal flow with textual rep' do
+      subject { executor.filter(:erb) }
+
       before do
         expect(Nanoc::Int::NotificationCenter)
           .to receive(:post).with(:filtering_started, rep, :erb)
         expect(Nanoc::Int::NotificationCenter)
           .to receive(:post).with(:filtering_ended, rep, :erb)
+
+        snapshot_repo.set(rep, :last, content)
       end
 
-      example do
-        executor.filter(:erb)
+      it 'does not set :pre on rep' do
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :pre) }
+      end
 
-        expect(rep.snapshot_contents[:last].string).to eq('Donkey Power')
-        expect(rep.snapshot_contents[:pre]).to be_nil
-        expect(rep.snapshot_contents[:post]).to be_nil
+      it 'does not set :post on rep' do
+        expect(snapshot_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :post) }
+      end
+
+      it 'updates :last on rep' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last).string }
+          .from('<%= "Donkey" %> Power')
+          .to('Donkey Power')
+      end
+
+      it 'does not set :pre in repo' do
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :pre) }
+      end
+
+      it 'does not set :post in repo' do
+        expect(snapshot_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :post) }
+      end
+
+      it 'updates :last in repo' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last).string }
+          .from('<%= "Donkey" %> Power')
+          .to('Donkey Power')
       end
 
       it 'returns frozen data' do
         executor.filter(:erb)
 
-        expect(rep.snapshot_contents[:last]).to be_frozen
+        expect(snapshot_repo.get(rep, :last)).to be_frozen
       end
     end
 
     context 'normal flow with binary rep' do
+      subject { executor.filter(:whatever) }
+
       let(:content) { Nanoc::Int::BinaryContent.new(File.expand_path('foo.dat')) }
 
       before do
@@ -73,25 +109,54 @@ describe Nanoc::Int::Executor do
         end
 
         expect(Nanoc::Filter).to receive(:named).with(:whatever) { filter_class }
+
+        snapshot_repo.set(rep, :last, content)
       end
 
-      example do
-        executor.filter(:whatever)
+      it 'does not set :pre on rep' do
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :pre) }
+      end
 
-        expect(File.read(rep.snapshot_contents[:last].filename))
-          .to match(/\ACompiled data for \/.*\/foo.dat\z/)
-        expect(rep.snapshot_contents[:pre]).to be_nil
-        expect(rep.snapshot_contents[:post]).to be_nil
+      it 'does not set :post on rep' do
+        expect(snapshot_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :post) }
+      end
+
+      it 'updates :last on rep' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last) }
+          .from(some_binary_content('Foo Data'))
+          .to(some_binary_content(/\ACompiled data for \/.*\/foo.dat\z/))
+      end
+
+      it 'does not set :pre in repo' do
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :pre) }
+      end
+
+      it 'does not set :post in repo' do
+        expect(snapshot_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :post) }
+      end
+
+      it 'updates :last in repo' do
+        expect { subject }
+          .to change { File.read(snapshot_repo.get(rep, :last).filename) }
+          .from('Foo Data')
+          .to(/\ACompiled data for \/.*\/foo.dat\z/)
       end
 
       it 'returns frozen data' do
         executor.filter(:whatever)
 
-        expect(rep.snapshot_contents[:last]).to be_frozen
+        expect(snapshot_repo.get(rep, :last)).to be_frozen
       end
     end
 
     context 'normal flow with binary rep and binary-to-text filter' do
+      subject { executor.filter(:whatever) }
+
       let(:content) { Nanoc::Int::BinaryContent.new(File.expand_path('foo.dat')) }
 
       before do
@@ -111,18 +176,48 @@ describe Nanoc::Int::Executor do
         end
 
         expect(Nanoc::Filter).to receive(:named).with(:whatever) { filter_class }
+
+        snapshot_repo.set(rep, :last, content)
       end
 
-      example do
-        executor.filter(:whatever)
+      it 'does not set :pre on rep' do
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :pre) }
+      end
 
-        expect(rep.snapshot_contents[:last].string).to match(/\ACompiled data for \/.*\/foo.dat\z/)
-        expect(rep.snapshot_contents[:pre]).to be_nil
-        expect(rep.snapshot_contents[:post]).to be_nil
+      it 'does not set :post on rep' do
+        expect(snapshot_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :post) }
+      end
+
+      it 'updates :last on rep' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last) }
+          .from(some_binary_content('Foo Data'))
+          .to(some_textual_content(/\ACompiled data for \/.*\/foo.dat\z/))
+      end
+
+      it 'does not set :pre in repo' do
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :pre) }
+      end
+
+      it 'does not set :post in repo' do
+        expect(snapshot_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :post) }
+      end
+
+      it 'updates :last in repo' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last) }
+          .from(some_binary_content('Foo Data'))
+          .to(some_textual_content(/\ACompiled data for \/.*\/foo.dat\z/))
       end
     end
 
     context 'normal flow with textual rep and text-to-binary filter' do
+      subject { executor.filter(:whatever) }
+
       before do
         expect(Nanoc::Int::NotificationCenter)
           .to receive(:post).with(:filtering_started, rep, :whatever)
@@ -138,15 +233,42 @@ describe Nanoc::Int::Executor do
         end
 
         expect(Nanoc::Filter).to receive(:named).with(:whatever) { filter_class }
+
+        snapshot_repo.set(rep, :last, content)
       end
 
-      example do
-        executor.filter(:whatever)
+      it 'does not set :pre on rep' do
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :pre) }
+      end
 
-        expect(File.read(rep.snapshot_contents[:last].filename))
-          .to eq('Binary <%= "Donkey" %> Power')
-        expect(rep.snapshot_contents[:pre]).to be_nil
-        expect(rep.snapshot_contents[:post]).to be_nil
+      it 'does not set :post on rep' do
+        expect(snapshot_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :post) }
+      end
+
+      it 'updates :last on rep' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last) }
+          .from(some_textual_content('<%= "Donkey" %> Power'))
+          .to(some_binary_content('Binary <%= "Donkey" %> Power'))
+      end
+
+      it 'does not set :pre in repo' do
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :pre) }
+      end
+
+      it 'does not set :post in repo' do
+        expect(snapshot_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { snapshot_repo.get(rep, :post) }
+      end
+
+      it 'updates :last in repo' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last) }
+          .from(some_textual_content('<%= "Donkey" %> Power'))
+          .to(some_binary_content('Binary <%= "Donkey" %> Power'))
       end
     end
 
@@ -166,6 +288,8 @@ describe Nanoc::Int::Executor do
         end
 
         expect(Nanoc::Filter).to receive(:named).with(:whatever) { filter_class }
+
+        snapshot_repo.set(rep, :last, content)
       end
 
       it 'raises' do
@@ -177,6 +301,10 @@ describe Nanoc::Int::Executor do
     context 'binary rep, text-to-something filter' do
       let(:content) { Nanoc::Int::BinaryContent.new(File.expand_path('foo.md')) }
 
+      before do
+        snapshot_repo.set(rep, :last, content)
+      end
+
       it 'raises' do
         expect { executor.filter(:erb) }
           .to raise_error(Nanoc::Int::Errors::CannotUseTextualFilter)
@@ -200,6 +328,8 @@ describe Nanoc::Int::Executor do
           def run(_filename, _params = {}); end
         end
 
+        snapshot_repo.set(rep, :last, content)
+
         expect(Nanoc::Filter).to receive(:named).with(:whatever) { filter_class }
       end
 
@@ -210,6 +340,10 @@ describe Nanoc::Int::Executor do
     end
 
     context 'content is frozen' do
+      before do
+        snapshot_repo.set(rep, :last, item.content)
+      end
+
       let(:item) do
         Nanoc::Int::Item.new('foo bar', {}, '/foo.md').tap(&:freeze)
       end
@@ -271,23 +405,26 @@ describe Nanoc::Int::Executor do
         items: double(:items),
         dependency_tracker: dependency_tracker,
         compilation_context: double(:compilation_context),
+        snapshot_repo: snapshot_repo,
       )
     end
 
-    let(:rule_memory) do
-      Nanoc::Int::RuleMemory.new(rep).tap do |mem|
-        mem.add_filter(:erb, {})
+    let(:action_sequence) do
+      Nanoc::Int::ActionSequence.build(rep) do |b|
+        b.add_filter(:erb, {})
       end
     end
 
     before do
-      rep.snapshot_defs = [Nanoc::Int::SnapshotDef.new(:pre)]
+      rep.snapshot_defs = [Nanoc::Int::SnapshotDef.new(:pre, binary: false)]
+
+      snapshot_repo.set(rep, :last, content)
 
       allow(compilation_context).to receive(:site) { site }
       allow(compilation_context).to receive(:assigns_for).with(rep, dependency_tracker) { assigns }
       allow(compilation_context).to receive(:create_view_context).with(dependency_tracker).and_return(view_context)
 
-      allow(action_provider).to receive(:memory_for).with(layout).and_return(rule_memory)
+      allow(action_provider).to receive(:action_sequence_for).with(layout).and_return(action_sequence)
     end
 
     subject { executor.layout('/default.*') }
@@ -299,30 +436,39 @@ describe Nanoc::Int::Executor do
         allow(dependency_tracker).to receive(:enter)
           .with(layout, raw_content: true, attributes: false, compiled_content: false, path: false)
         allow(dependency_tracker).to receive(:enter)
-          .with(layout, raw_content: false, attributes: true, compiled_content: false, path: false)
+          .with(layout, raw_content: false, attributes: [:bug], compiled_content: false, path: false)
         allow(dependency_tracker).to receive(:exit)
         subject
-        expect(rep.snapshot_contents[:last].string).to eq('head Gum Emperor foot')
+        expect(snapshot_repo.get(rep, :last).string).to eq('head Gum Emperor foot')
       end
     end
 
     context 'normal flow' do
-      it 'updates last content' do
-        subject
-        expect(rep.snapshot_contents[:last].string).to eq('head hallo foot')
+      it 'updates :last on rep' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last) }
+          .from(some_textual_content('Donkey Power'))
+          .to(some_textual_content('head hallo foot'))
+      end
+
+      it 'updates :last in repo' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :last) }
+          .from(some_textual_content('Donkey Power'))
+          .to(some_textual_content('head hallo foot'))
       end
 
       it 'sets frozen content' do
         subject
-        expect(rep.snapshot_contents[:last]).to be_frozen
-        expect(rep.snapshot_contents[:pre]).to be_frozen
+        expect(snapshot_repo.get(rep, :last)).to be_frozen
+        expect(snapshot_repo.get(rep, :pre)).to be_frozen
       end
 
       it 'does not create pre snapshot' do
         # a #layout is followed by a #snapshot(:pre, …)
-        expect(rep.snapshot_contents[:pre]).to be_nil
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
         subject
-        expect(rep.snapshot_contents[:pre]).to be_nil
+        expect(snapshot_repo.get(rep, :pre)).to be_nil
       end
 
       it 'sends notifications' do
@@ -343,18 +489,36 @@ describe Nanoc::Int::Executor do
           executor.snapshot(:pre)
         end
 
-        it 'can contain compiled_content reference' do
-          subject
-          expect(rep.snapshot_contents[:last].string).to eq('head Donkey Power foot')
+        it 'updates :last on rep' do
+          expect { subject }
+            .to change { snapshot_repo.get(rep, :last) }
+            .from(some_textual_content('Donkey Power'))
+            .to(some_textual_content('head Donkey Power foot'))
+        end
+
+        it 'updates :last in repo' do
+          expect { subject }
+            .to change { snapshot_repo.get(rep, :last) }
+            .from(some_textual_content('Donkey Power'))
+            .to(some_textual_content('head Donkey Power foot'))
         end
       end
 
       context 'content with layout reference' do
         let(:layout_content) { 'head <%= @layout.identifier %> foot' }
 
-        it 'includes layout in assigns' do
-          subject
-          expect(rep.snapshot_contents[:last].string).to eq('head /default.erb foot')
+        it 'updates :last on rep' do
+          expect { subject }
+            .to change { snapshot_repo.get(rep, :last) }
+            .from(some_textual_content('Donkey Power'))
+            .to(some_textual_content('head /default.erb foot'))
+        end
+
+        it 'updates :last in repo' do
+          expect { subject }
+            .to change { snapshot_repo.get(rep, :last) }
+            .from(some_textual_content('Donkey Power'))
+            .to(some_textual_content('head /default.erb foot'))
         end
       end
     end
@@ -370,8 +534,8 @@ describe Nanoc::Int::Executor do
     end
 
     context 'no filter specified' do
-      let(:rule_memory) do
-        Nanoc::Int::RuleMemory.new(rep)
+      let(:action_sequence) do
+        Nanoc::Int::ActionSequence.new(rep)
       end
 
       it 'raises' do
@@ -383,7 +547,10 @@ describe Nanoc::Int::Executor do
       let(:content) { Nanoc::Int::BinaryContent.new(File.expand_path('donkey.md')) }
 
       it 'raises' do
-        expect { subject }.to raise_error(Nanoc::Int::Errors::CannotLayoutBinaryItem)
+        expect { subject }.to raise_error(
+          Nanoc::Int::Errors::CannotLayoutBinaryItem,
+          'The “/index.md” item (rep “donkey”) cannot be laid out because it is a binary item. If you are getting this error for an item that should be textual instead of binary, make sure that its extension is included in the text_extensions array in the site configuration.',
+        )
       end
     end
 
@@ -402,23 +569,47 @@ describe Nanoc::Int::Executor do
   end
 
   describe '#snapshot' do
+    subject { executor.snapshot(:something) }
+
+    before do
+      snapshot_repo.set(rep, :last, content)
+
+      File.write('donkey.dat', 'binary donkey')
+    end
+
     context 'binary content' do
       let(:content) { Nanoc::Int::BinaryContent.new(File.expand_path('donkey.dat')) }
 
-      it 'creates snapshots' do
-        executor.snapshot(:something)
+      it 'creates snapshots on rep' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :something) }
+          .from(nil)
+          .to(some_binary_content('binary donkey'))
+      end
 
-        expect(rep.snapshot_contents[:something]).not_to be_nil
+      it 'creates snapshots in repo' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :something) }
+          .from(nil)
+          .to(some_binary_content('binary donkey'))
       end
     end
 
     context 'textual content' do
       let(:content) { Nanoc::Int::TextualContent.new('Donkey Power') }
 
-      it 'creates a snapshot' do
-        executor.snapshot(:something)
+      it 'creates snapshots on rep' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :something) }
+          .from(nil)
+          .to(some_textual_content('Donkey Power'))
+      end
 
-        expect(rep.snapshot_contents[:something].string).to eq('Donkey Power')
+      it 'creates snapshots in repo' do
+        expect { subject }
+          .to change { snapshot_repo.get(rep, :something) }
+          .from(nil)
+          .to(some_textual_content('Donkey Power'))
       end
     end
 
@@ -427,7 +618,7 @@ describe Nanoc::Int::Executor do
 
       context 'raw path' do
         before do
-          rep.raw_paths = { something: 'output/donkey.md' }
+          rep.raw_paths = { something: ['output/donkey.md'] }
         end
 
         it 'does not write' do
