@@ -1,5 +1,8 @@
+# frozen_string_literal: true
+
 describe Nanoc::MutableLayoutCollectionView do
   let(:view_class) { Nanoc::MutableLayoutView }
+  let(:collection_class) { Nanoc::Int::LayoutCollection }
   it_behaves_like 'an identifiable collection'
   it_behaves_like 'a mutable identifiable collection'
 
@@ -13,9 +16,7 @@ describe Nanoc::MutableLayoutCollectionView do
     end
 
     let(:wrapped) do
-      Nanoc::Int::IdentifiableCollection.new(config).tap do |coll|
-        coll << layout
-      end
+      Nanoc::Int::LayoutCollection.new(config, [layout])
     end
 
     let(:view) { described_class.new(wrapped, nil) }
@@ -23,8 +24,15 @@ describe Nanoc::MutableLayoutCollectionView do
     it 'creates an object' do
       view.create('new content', { title: 'New Page' }, '/new/')
 
-      expect(wrapped.size).to eq(2)
-      expect(wrapped['/new/'].content.string).to eq('new content')
+      expect(view.unwrap.size).to eq(2)
+      expect(view.unwrap['/new/'].content.string).to eq('new content')
+    end
+
+    it 'does not update wrapped' do
+      view.create('new content', { title: 'New Page' }, '/new/')
+
+      expect(wrapped.size).to eq(1)
+      expect(wrapped['/new']).to be_nil
     end
 
     it 'returns self' do
@@ -35,7 +43,7 @@ describe Nanoc::MutableLayoutCollectionView do
 
   describe '#inspect' do
     let(:wrapped) do
-      Nanoc::Int::IdentifiableCollection.new(config)
+      Nanoc::Int::LayoutCollection.new(config)
     end
 
     let(:view) { described_class.new(wrapped, view_context) }
