@@ -1,4 +1,6 @@
-describe Nanoc::CLI::Commands::Compile::Listener do
+# frozen_string_literal: true
+
+describe Nanoc::CLI::Commands::CompileListeners::Abstract do
   let(:klass) do
     Class.new(described_class) do
       attr_reader :started
