@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 describe 'GH-1040', site: true, stdio: true do
   before do
     File.write('content/foo.txt', 'bar=<%= @items["/bar.*"].compiled_content %>')
@@ -17,6 +19,6 @@ EOS
   end
 
   it 'errors' do
-    expect { Nanoc::CLI.run(%w(compile)) }.to raise_error(Nanoc::Int::Errors::RecursiveCompilation)
+    expect { Nanoc::CLI.run(%w[compile]) }.to raise_error(Nanoc::Int::Errors::DependencyCycle)
   end
 end
