@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 describe 'GH-882', site: true, stdio: true do
   before do
     File.write('content/foo.md', 'I am foo!')
@@ -18,12 +20,12 @@ EOS
   end
 
   example do
-    Nanoc::CLI.run(%w(compile))
+    Nanoc::CLI.run(%w[compile])
 
     File.write('content/bar.md', 'I am bar! Modified!')
-    expect { Nanoc::CLI.run(%w(compile)) }.to output(%r{^Modified: /bar.md - default$}).to_stdout
+    expect { Nanoc::CLI.run(%w[compile]) }.to output(%r{^Modified: /bar.md - default$}).to_stdout
 
     File.write('content/bar.md', 'I am bar! Modified again!')
-    expect { Nanoc::CLI.run(%w(compile)) }.not_to output(%r{^Modified: /foo.md - default$}).to_stdout
+    expect { Nanoc::CLI.run(%w[compile]) }.not_to output(%r{^Modified: /foo.md - default$}).to_stdout
   end
 end
