@@ -1,45 +1,8 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class Nanoc::Int::CompilerTest < Nanoc::TestCase
-  def new_compiler(site = nil)
-    site ||= Nanoc::Int::Site.new(
-      config: nil,
-      code_snippets: [],
-      items: [],
-      layouts: [],
-    )
-
-    reps = Nanoc::Int::ItemRepRepo.new
-
-    action_provider = Nanoc::Int::ActionProvider.named(:rule_dsl).for(site)
-
-    objects = site.items.to_a + site.layouts.to_a
-
-    params = {
-      compiled_content_cache: Nanoc::Int::CompiledContentCache.new(items: site.items),
-      checksum_store: Nanoc::Int::ChecksumStore.new(site: site, objects: objects),
-      rule_memory_store: Nanoc::Int::RuleMemoryStore.new,
-      dependency_store: Nanoc::Int::DependencyStore.new(
-        site.items.to_a + site.layouts.to_a,
-      ),
-      action_provider: action_provider,
-      reps: reps,
-      outdatedness_store: Nanoc::Int::OutdatednessStore.new(site: site, reps: reps),
-    }
-
-    params[:outdatedness_checker] =
-      Nanoc::Int::OutdatednessChecker.new(
-        site: site,
-        checksum_store: params[:checksum_store],
-        dependency_store: params[:dependency_store],
-        rule_memory_store: params[:rule_memory_store],
-        action_provider: action_provider,
-        reps: reps,
-      )
-
-    Nanoc::Int::Compiler.new(site, params)
-  end
-
   def test_compile_rep_should_write_proper_snapshots_real
     with_site do |site|
       File.write('content/moo.txt', '<%= 1 %> <%%= 2 %> <%%%= 3 %>')
@@ -76,11 +39,11 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
       site.compile
 
       assert File.file?('output/moo-raw.txt')
-      # assert File.file?('output/moo-pre.txt')
+      assert File.file?('output/moo-pre.txt')
       assert File.file?('output/moo-post.txt')
       assert File.file?('output/moo-last.txt')
       assert_equal '<%= 1 %> <%%= 2 %> <%%%= 3 %>', File.read('output/moo-raw.txt')
-      # assert_equal '1 2 <%= 3 %>',                  File.read('output/moo-pre.txt')
+      assert_equal '1 2 <%= 3 %>',                  File.read('output/moo-pre.txt')
       assert_equal 'head 1 2 3 foot',               File.read('output/moo-post.txt')
       assert_equal 'head 1 2 3 foot',               File.read('output/moo-last.txt')
     end
@@ -153,7 +116,7 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
       end
 
       site = Nanoc::Int::SiteLoader.new.new_from_cwd
-      assert_raises Nanoc::Int::Errors::RecursiveCompilation do
+      assert_raises Nanoc::Int::Errors::DependencyCycle do
         site.compile
       end
     end
@@ -161,7 +124,7 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
 
   def test_disallow_routes_not_starting_with_slash
     # Create site
-    Nanoc::CLI.run %w(create_site bar)
+    Nanoc::CLI.run %w[create_site bar]
 
     FileUtils.cd('bar') do
       # Create routes
@@ -188,7 +151,7 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
 
   def test_disallow_duplicate_routes
     # Create site
-    Nanoc::CLI.run %w(create_site bar)
+    Nanoc::CLI.run %w[create_site bar]
 
     FileUtils.cd('bar') do
       # Create routes
@@ -215,7 +178,7 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
 
   def test_disallow_multiple_snapshots_with_the_same_name
     # Create site
-    Nanoc::CLI.run %w(create_site bar)
+    Nanoc::CLI.run %w[create_site bar]
 
     FileUtils.cd('bar') do
       # Create routes
@@ -437,8 +400,8 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
       site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
-      assert_equal Set.new(%w(content/blah.dat)), Set.new(Dir['content/*'])
-      assert_equal Set.new(%w(output/blah.dat)), Set.new(Dir['output/*'])
+      assert_equal Set.new(%w[content/blah.dat]), Set.new(Dir['content/*'])
+      assert_equal Set.new(%w[output/blah.dat]), Set.new(Dir['output/*'])
     end
   end
 
@@ -459,7 +422,7 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
   end
 
   def test_find_layouts_by_glob
-    Nanoc::CLI.run %w(create_site bar)
+    Nanoc::CLI.run %w[create_site bar]
     FileUtils.cd('bar') do
       File.open('Rules', 'w') do |io|
         io.write "compile '/**/*' do\n"
