@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class Nanoc::CLI::Commands::InfoTest < Nanoc::TestCase
   def test_run
-    Nanoc::CLI.run %w(info)
+    Nanoc::CLI.run %w[info]
   end
 end
