@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class Nanoc::CLI::CleaningStreamTest < Nanoc::TestCase
@@ -20,7 +22,7 @@ class Nanoc::CLI::CleaningStreamTest < Nanoc::TestCase
   end
 
   def test_forward
-    methods = [:write, :<<, :tty?, :tty?, :flush, :tell, :print, :puts, :string, :reopen, :exist?, :exists?, :close]
+    methods = %i[write << tty? tty? flush tell print puts string reopen exist? exists? close]
 
     s = Stream.new
     cs = Nanoc::CLI::CleaningStream.new(s)
@@ -84,4 +86,12 @@ class Nanoc::CLI::CleaningStreamTest < Nanoc::TestCase
     cleaning_stream << obj
     assert_equal 'Hello… world!', stream.string
   end
+
+  def test_invalid_string
+    s = "\x80"
+    stream = StringIO.new
+    cleaning_stream = Nanoc::CLI::CleaningStream.new(stream)
+    cleaning_stream << s
+    assert_equal "\xef\xbf\xbd", stream.string
+  end
 end
