@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
@@ -486,12 +488,6 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
   end
 
   def test_compile_iso_8859_1_site
-    # Check encoding
-    unless ''.respond_to?(:encode)
-      skip 'Test only works on 1.9.x'
-      return
-    end
-
     # Create data source
     data_source = new_data_source
 
@@ -514,12 +510,6 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
   end
 
   def test_compile_iso_8859_1_site_with_explicit_encoding
-    # Check encoding
-    unless ''.respond_to?(:encode)
-      skip 'Test only works on 1.9.x'
-      return
-    end
-
     # Create data source
     data_source = new_data_source({})
     data_source.config[:encoding] = 'ISO-8859-1'
@@ -547,12 +537,12 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     # Write sample files
     FileUtils.mkdir_p('foo')
-    %w(foo.html foo.yaml bar.entry.html foo/qux.yaml).each do |filename|
+    %w[foo.html foo.yaml bar.entry.html foo/qux.yaml].each do |filename|
       File.open(filename, 'w') { |io| io.write('test') }
     end
 
     # Write stray files
-    %w(foo.html~ foo.yaml.orig bar.entry.html.bak).each do |filename|
+    %w[foo.html~ foo.yaml.orig bar.entry.html.bak].each do |filename|
       File.open(filename, 'w') { |io| io.write('test') }
     end
 
@@ -574,12 +564,12 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     # Write sample files
     FileUtils.mkdir_p('foo')
-    %w(foo.html foo.yaml bar.html.erb foo/qux.yaml).each do |filename|
+    %w[foo.html foo.yaml bar.html.erb foo/qux.yaml].each do |filename|
       File.open(filename, 'w') { |io| io.write('test') }
     end
 
     # Write stray files
-    %w(foo.html~ foo.yaml.orig bar.entry.html.bak).each do |filename|
+    %w[foo.html~ foo.yaml.orig bar.entry.html.bak].each do |filename|
       File.open(filename, 'w') { |io| io.write('test') }
     end
 
@@ -600,7 +590,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, nil)
 
     # Write sample files
-    %w(aaa/foo.html bbb/foo.html ccc/foo.html).each do |filename|
+    %w[aaa/foo.html bbb/foo.html ccc/foo.html].each do |filename|
       FileUtils.mkdir_p(File.dirname(filename))
       File.open(filename, 'w') { |io| io.write('test') }
     end
@@ -620,7 +610,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, config)
 
     # Write sample files
-    %w(stuff/foo.html stuff/foo.md stuff/foo.yaml).each do |filename|
+    %w[stuff/foo.html stuff/foo.md stuff/foo.yaml].each do |filename|
       FileUtils.mkdir_p(File.dirname(filename))
       File.open(filename, 'w') { |io| io.write('test') }
     end
@@ -631,7 +621,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     assert_equal 2, res.values[0].size
     assert_equal 'yaml', res.values[0][0]
     assert_equal Array, res.values[0][1].class
-    assert_equal %w(html md), res.values[0][1].sort
+    assert_equal %w[html md], res.values[0][1].sort
   end
 
   def test_all_split_files_in_with_multiple_content_files
@@ -639,7 +629,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, nil)
 
     # Write sample files
-    %w(foo.html foo.xhtml foo.txt foo.yaml bar.html qux.yaml).each do |filename|
+    %w[foo.html foo.xhtml foo.txt foo.yaml bar.html qux.yaml].each do |filename|
       File.open(filename, 'w') { |io| io.write('test') }
     end
 
@@ -649,6 +639,32 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     end
   end
 
+  def test_basename_of_with_full_style_identifiers
+    # Create data source
+    config = { identifier_type: 'full' }
+    data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, config)
+
+    # Get input and expected output
+    expected = {
+      '/'                 => '/',
+      '/foo'              => '/foo',
+      '/foo.html'         => '/foo',
+      '/foo.xyz.html'     => '/foo.xyz',
+      '/foo/bar'          => '/foo/bar',
+      '/foo/bar.html'     => '/foo/bar',
+      '/foo/bar.xyz.html' => '/foo/bar.xyz',
+    }
+
+    # Check
+    expected.each_pair do |input, expected_output|
+      actual_output = data_source.send(:basename_of, input)
+      assert_equal(
+        expected_output, actual_output,
+        "basename_of(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
+      )
+    end
+  end
+
   def test_basename_of_allowing_periods_in_identifiers
     # Create data source
     data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, allow_periods_in_identifiers: true)
