@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
@@ -15,7 +17,7 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -41,7 +43,7 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -67,7 +69,7 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -93,20 +95,20 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
-    raw_content = <<EOS
-<!DOCTYPE html>
-<html>
-  <head>
-    <title>Hello</title>
-  </head>
-  <body>
-    <a href=/foo>foo</a>
-  </body>
-</html>
+    raw_content = <<~EOS
+      <!DOCTYPE html>
+      <html>
+        <head>
+          <title>Hello</title>
+        </head>
+        <body>
+          <a href=/foo>foo</a>
+        </body>
+      </html>
 EOS
     expected0 = %r{<a href="\.\./\.\.">foo</a>}
     expected1 = %r{\A\s*<!DOCTYPE html\s*>\s*<html>\s*<head>(.|\s)*<title>Hello</title>\s*</head>\s*<body>\s*<a href="../..">foo</a>\s*</body>\s*</html>\s*\Z}m
@@ -117,6 +119,44 @@ EOS
     assert_match(expected1, actual_content)
   end
 
+  def test_filter_html5_with_boilerplate
+    # Create filter with mock item
+    filter = Nanoc::Filters::RelativizePaths.new
+
+    # Mock item
+    filter.instance_eval do
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
+          'content',
+          {},
+          '/foo/bar/baz/',
+        ),
+        :blah,
+      )
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
+    end
+
+    # Set content
+    raw_content = <<~EOS
+      <!DOCTYPE html>
+      <html>
+        <head>
+          <title>Hello</title>
+        </head>
+        <body>
+          <a href=/foo>foo</a>
+        </body>
+      </html>
+EOS
+    expected0 = %r{<a href="\.\./\.\.">foo</a>}
+    expected1 = %r{\A\s*<!DOCTYPE html\s*>\s*<html>\s*<head>\s*<title>Hello</title>\s*</head>\s*<body>\s*<a href="../..">foo</a>\s*</body>\s*</html>\s*\Z}m
+
+    # Test
+    actual_content = filter.setup_and_run(raw_content, type: :html5)
+    assert_match(expected0, actual_content)
+    assert_match(expected1, actual_content)
+  end
+
   def test_filter_html_multiple
     # Create filter with mock item
     filter = Nanoc::Filters::RelativizePaths.new
@@ -131,7 +171,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -157,7 +197,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -183,7 +223,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -209,7 +249,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/woof/meow/'
+      @item_rep.paths[:last] = ['/woof/meow/']
     end
 
     # Set content
@@ -235,7 +275,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/woof/meow/'
+      @item_rep.paths[:last] = ['/woof/meow/']
     end
 
     # Set content
@@ -261,7 +301,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/woof/meow/'
+      @item_rep.paths[:last] = ['/woof/meow/']
     end
 
     # Set content
@@ -287,7 +327,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/woof/meow/'
+      @item_rep.paths[:last] = ['/woof/meow/']
     end
 
     # Set content
@@ -313,7 +353,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/woof/meow/'
+      @item_rep.paths[:last] = ['/woof/meow/']
     end
 
     # Set content
@@ -339,7 +379,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/woof/meow/'
+      @item_rep.paths[:last] = ['/woof/meow/']
     end
 
     raw_content    = %(<object data="/example"><param name="movie" content="/example"></object>)
@@ -363,7 +403,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -399,7 +439,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -425,7 +465,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -451,7 +491,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -477,7 +517,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
@@ -506,7 +546,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/woof/meow/'
+      @item_rep.paths[:last] = ['/woof/meow/']
     end
 
     # Set content
@@ -532,7 +572,7 @@ EOS
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/woof/meow/'
+      @item_rep.paths[:last] = ['/woof/meow/']
     end
 
     # Set content
@@ -559,16 +599,16 @@ EOS
           ),
           :blah,
         )
-        @item_rep.paths[:last] = '/foo/bar/baz/'
+        @item_rep.paths[:last] = ['/foo/bar/baz/']
       end
 
       # Set content
       expected = /<bar boo="\.\.\/\.\.">baz<\/bar>/
-      raw_content = <<-XML
-<?xml version="1.0" encoding="utf-8"?>
-<foo>
-  <bar boo="/foo">baz</bar>
-</foo>
+      raw_content = <<~XML
+        <?xml version="1.0" encoding="utf-8"?>
+        <foo>
+          <bar boo="/foo">baz</bar>
+        </foo>
 XML
 
       actual_content = filter.setup_and_run(raw_content, type: :xml, select: ['*/@boo'])
@@ -592,14 +632,14 @@ XML
           ),
           :blah,
         )
-        @item_rep.paths[:last] = '/foo/bar/baz/'
+        @item_rep.paths[:last] = ['/foo/bar/baz/']
       end
 
       # Set content
-      raw_content = <<-XML
-<foo>
-  <bar><far href="/foo">baz</far></bar>
-</foo>
+      raw_content = <<~XML
+        <foo>
+          <bar><far href="/foo">baz</far></bar>
+        </foo>
 XML
 
       actual_content = filter.setup_and_run(raw_content, type: :xml, select: ['far/@href'])
@@ -624,14 +664,14 @@ XML
           ),
           :blah,
         )
-        @item_rep.paths[:last] = '/foo/bar/baz/'
+        @item_rep.paths[:last] = ['/foo/bar/baz/']
       end
 
       # Set content
-      raw_content = <<-XML
-<foo xmlns="http://example.org">
-  <bar><a href="/foo">baz</a></bar>
-</foo>
+      raw_content = <<~XML
+        <foo xmlns="http://example.org">
+          <bar><a href="/foo">baz</a></bar>
+        </foo>
 XML
 
       options = {
@@ -661,22 +701,22 @@ XML
           ),
           :blah,
         )
-        @item_rep.paths[:last] = '/foo/bar/baz/'
+        @item_rep.paths[:last] = ['/foo/bar/baz/']
       end
 
       # Set content
-      raw_content = <<-XML
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
-  <head>
-    <link rel="stylesheet" href="/css"/>
-    <script src="/js"></script>
-  </head>
-  <body>
-    <a href="/foo">bar</a>
-    <img src="/img"/>
-  </body>
-</html>
+      raw_content = <<~XML
+        <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
+        <html xmlns="http://www.w3.org/1999/xhtml">
+          <head>
+            <link rel="stylesheet" href="/css"/>
+            <script src="/js"></script>
+          </head>
+          <body>
+            <a href="/foo">bar</a>
+            <img src="/img"/>
+          </body>
+        </html>
 XML
 
       actual_content = filter.setup_and_run(raw_content, type: :xhtml)
@@ -703,15 +743,15 @@ XML
           ),
           :blah,
         )
-        @item_rep.paths[:last] = '/foo/bar/baz/'
+        @item_rep.paths[:last] = ['/foo/bar/baz/']
       end
 
       # Set content
-      raw_content = <<-XML
-<a href="/foo">bar</a>
-<p>
-  <img src="/img"/>
-</p>
+      raw_content = <<~XML
+        <a href="/foo">bar</a>
+        <p>
+          <img src="/img"/>
+        </p>
 XML
 
       expected_content =
@@ -738,7 +778,7 @@ XML
           ),
           :blah,
         )
-        @item_rep.paths[:last] = '/foo/baz/'
+        @item_rep.paths[:last] = ['/foo/baz/']
       end
 
       # Set content
@@ -772,7 +812,7 @@ XML
           ),
           :blah,
         )
-        @item_rep.paths[:last] = '/foo/baz/'
+        @item_rep.paths[:last] = ['/foo/baz/']
       end
 
       # Set content
@@ -803,7 +843,7 @@ XML
         ),
         :blah,
       )
-      @item_rep.paths[:last] = '/foo/bar/baz/'
+      @item_rep.paths[:last] = ['/foo/bar/baz/']
     end
 
     # Set content
