@@ -1,9 +1,9 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class Nanoc::Filters::UglifyJSTest < Nanoc::TestCase
   def test_filter
-    skip_v8_on_ruby24
-
     if_have 'uglifier' do
       # Create filter
       filter = ::Nanoc::Filters::UglifyJS.new
@@ -16,8 +16,6 @@ class Nanoc::Filters::UglifyJSTest < Nanoc::TestCase
   end
 
   def test_filter_with_options
-    skip_v8_on_ruby24
-
     if_have 'uglifier' do
       filter = ::Nanoc::Filters::UglifyJS.new
       input = "if(donkey) alert('It is a donkey!');"
