@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
@@ -26,6 +28,24 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     item
   end
 
+  def setup
+    super
+
+    config = Nanoc::Int::Configuration.new.with_defaults
+    items = Nanoc::Int::ItemCollection.new(config)
+    layouts = Nanoc::Int::LayoutCollection.new(config)
+    dep_store = Nanoc::Int::DependencyStore.new(items, layouts, config)
+    dependency_tracker = Nanoc::Int::DependencyTracker.new(dep_store)
+
+    @view_context = Nanoc::ViewContext.new(
+      reps: :__irrelevant__,
+      items: nil,
+      dependency_tracker: dependency_tracker,
+      compilation_context: :__irrelevant__,
+      snapshot_repo: :__irrelevant_snapshot_repo,
+    )
+  end
+
   def test_atom_feed
     if_have 'builder' do
       # Create items
@@ -49,7 +69,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[2].expects(:compiled_content).with(snapshot: :pre).returns('item 2 content')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -80,7 +101,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[2].expects(:compiled_content).returns('item 2 content')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -111,7 +133,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[2].expects(:compiled_content).returns('item 2 content')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -142,7 +165,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[2].expects(:compiled_content).returns('item 2 content')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -163,7 +187,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_item]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -188,7 +213,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_article]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: nil }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: nil })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -213,7 +239,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_article]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -238,7 +265,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_article]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -268,7 +296,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[0].expects(:compiled_content).returns('item 1 content')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com/' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com/' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -310,7 +339,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_article]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -337,7 +367,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[2].stubs(:[]).with(:created_at).returns(nil)
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -363,7 +394,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -388,15 +420,15 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
-      @config = Nanoc::ConfigView.new(
+      config_hash =
         {
           author_name: 'Bob',
           author_uri: 'http://example.com/~bob/',
           title: 'My Blog Or Something',
           base_url: 'http://example.com',
-        },
-        nil,
-      )
+        }
+      config = Nanoc::Int::Configuration.new(hash: config_hash)
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -420,7 +452,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -444,7 +477,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       end
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -477,7 +511,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].stubs(:[]).with(:created_at).returns('22-03-2009')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -506,7 +541,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].stubs(:[]).with(:created_at).returns('01-01-2014')
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -530,7 +566,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_article]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -551,7 +588,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_article]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -572,7 +610,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_article]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -593,7 +632,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_article]
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -608,6 +648,28 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     end
   end
 
+  def test_atom_feed_with_xml_base
+    if_have 'builder' do
+      # Mock article
+      @items = [mock_article]
+
+      # Mock site
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
+
+      # Create feed item
+      @item = mock
+      @item.stubs(:[]).with(:title).returns('My Blog Or Something')
+      @item.stubs(:[]).with(:author_name).returns('J. Doe')
+      @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
+      @item.stubs(:[]).with(:feed_url).returns('http://example.com/feed')
+
+      # Check
+      result = atom_feed
+      assert_match 'xml:base="http://example.com/"', result
+    end
+  end
+
   def test_atom_feed_with_item_without_path
     if_have 'builder' do
       # Create items
@@ -615,7 +677,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[0].stubs(:path).returns(nil)
 
       # Mock site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
