@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
@@ -6,9 +8,20 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def setup
     super
 
+    config = Nanoc::Int::Configuration.new.with_defaults
+    items = Nanoc::Int::ItemCollection.new(config)
+    layouts = Nanoc::Int::LayoutCollection.new(config)
+    dep_store = Nanoc::Int::DependencyStore.new(items, layouts, config)
+    dependency_tracker = Nanoc::Int::DependencyTracker.new(dep_store)
+
     @reps = Nanoc::Int::ItemRepRepo.new
-    dependency_tracker = Nanoc::Int::DependencyTracker.new(nil)
-    @view_context = Nanoc::ViewContext.new(reps: @reps, items: nil, dependency_tracker: dependency_tracker, compilation_context: :__irrelevant__)
+    @view_context = Nanoc::ViewContext.new(
+      reps: @reps,
+      items: nil,
+      dependency_tracker: dependency_tracker,
+      compilation_context: :__irrelevant__,
+      snapshot_repo: :__irrelevant_snapshot_repo,
+    )
 
     @items = nil
     @item = nil
@@ -19,35 +32,39 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def test_xml_sitemap
     if_have 'builder', 'nokogiri' do
       # Create items
-      @items = Nanoc::Int::IdentifiableCollection.new({})
+      items = []
 
       # Create item 1
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/item-one/'), @view_context)
-      @items << item
+      items << item
       create_item_rep(item.unwrap, :one_a, '/item-one/a/')
       create_item_rep(item.unwrap, :one_b, '/item-one/b/')
 
       # Create item 2
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 2', { is_hidden: true }, '/item-two/'), @view_context)
-      @items << item
+      items << item
 
       # Create item 3
       attrs = { mtime: Time.parse('2004-07-12 00:00:00 +02:00'), changefreq: 'daily', priority: 0.5 }
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 3', attrs, '/item-three/'), @view_context)
-      @items << item
+      items << item
       create_item_rep(item.unwrap, :three_a, '/item-three/a/')
       create_item_rep(item.unwrap, :three_b, '/item-three/b/')
 
       # Create item 4
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 4', {}, '/item-four/'), @view_context)
-      @items << item
+      items << item
       create_item_rep(item.unwrap, :four_a, nil)
 
+      # Create items
+      @items = Nanoc::Int::ItemCollection.new({}, items)
+
       # Create sitemap item
       @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/'), @view_context)
 
       # Create site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Build sitemap
       res = xml_sitemap
@@ -80,19 +97,21 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def test_sitemap_with_items_as_param
     if_have 'builder', 'nokogiri' do
       # Create items
-      @items = Nanoc::Int::IdentifiableCollection.new({})
-      @items << nil
+      items = []
+      items << nil
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/item-one/'), @view_context)
-      @items << item
+      items << item
       create_item_rep(item.unwrap, :one_a, '/item-one/a/')
       create_item_rep(item.unwrap, :one_b, '/item-one/b/')
-      @items << nil
+      items << nil
+      @items = Nanoc::Int::ItemCollection.new({})
 
       # Create sitemap item
       @item = Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/')
 
       # Create site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Build sitemap
       res = xml_sitemap(items: [item])
@@ -117,9 +136,8 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def test_filter
     if_have 'builder', 'nokogiri' do
       # Create items
-      @items = Nanoc::Int::IdentifiableCollection.new({})
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/item-one/'), @view_context)
-      @items << item
+      @items = Nanoc::Int::ItemCollection.new({}, [item])
       create_item_rep(item.unwrap, :one_a, '/item-one/a/')
       create_item_rep(item.unwrap, :one_b, '/item-one/b/')
 
@@ -127,7 +145,8 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
       @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/'), @view_context)
 
       # Create site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Build sitemap
       res = xml_sitemap(rep_select: ->(rep) { rep.name == :one_a })
@@ -148,25 +167,27 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def test_sorted
     if_have 'builder', 'nokogiri' do
       # Create items
-      @items = Nanoc::Int::IdentifiableCollection.new({})
+      items = []
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/george/'), @view_context)
-      @items << item
+      items << item
       create_item_rep(item.unwrap, :a_alice,   '/george/alice/')
       create_item_rep(item.unwrap, :b_zoey,    '/george/zoey/')
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/walton/'), @view_context)
-      @items << item
+      items << item
       create_item_rep(item.unwrap, :a_eve,     '/walton/eve/')
       create_item_rep(item.unwrap, :b_bob,     '/walton/bob/')
       item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/lucas/'), @view_context)
-      @items << item
+      items << item
       create_item_rep(item.unwrap, :a_trudy,   '/lucas/trudy/')
       create_item_rep(item.unwrap, :b_mallory, '/lucas/mallory/')
+      @items = Nanoc::Int::ItemCollection.new({}, items)
 
       # Create sitemap item
       @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/'), @view_context)
 
       # Create site
-      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
 
       # Build sitemap
       res = xml_sitemap(items: @items)
@@ -186,12 +207,39 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
     end
   end
 
+  def test_url_escape
+    if_have 'builder', 'nokogiri' do
+      # Create items
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/george/'), @view_context)
+      @items = Nanoc::Int::ItemCollection.new({}, [item])
+      create_item_rep(item.unwrap, :default, '/cool projects/проверка')
+
+      # Create sitemap item
+      @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/'), @view_context)
+
+      # Create site
+      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new(config, @view_context)
+
+      # Build sitemap
+      res = xml_sitemap(items: @items)
+
+      # Check
+      doc = Nokogiri::XML(res)
+      urlsets = doc.css('> urlset')
+      assert_equal 1, urlsets.size
+      urls = urlsets.css('> url')
+      assert_equal 1, urls.size
+      assert_equal 'http://example.com/cool%20projects/%D0%BF%D1%80%D0%BE%D0%B2%D0%B5%D1%80%D0%BA%D0%B0', urls[0].css('> loc').inner_text
+    end
+  end
+
   protected
 
   def create_item_rep(item, name, path)
     rep = Nanoc::Int::ItemRep.new(item, name)
-    rep.paths     = { last: path }
-    rep.raw_paths = { last: path }
+    rep.paths     = { last: (path ? [path] : []) }
+    rep.raw_paths = { last: (path ? [path] : []) }
     @reps << rep
     rep
   end
